(get-started)=
# Get Started

:::{toctree}
:maxdepth: 1
:hidden:
install.md
evaluation.md
testset_generation.md
monitoring.md
:::

Welcome to the Ragas tutorials! These begineer-friendly tutorials will guide you
through the fundamentals of working with Ragas. These tutorials do assume basic
knowledge of Python and Retrieval Augmented Generation (RAG) pipelines. 

Before you go further make sure you have [Ragas installed](./install.md)!

:::{note}
The tutorials only give you on overview of what you can do with ragas and the
basic skill you need to use it. If you want an in-depth explaination of the
core-concepts behind Ragas, check out the [Core Concepts](../concepts/index.md) page. You can also checkout the [How-to Guides](../howtos/index.md) if you want to specific applications of Ragas.
:::


If you have any questions about Ragas, feel free to join and ask in the
`#questions` channel in our discord community ❤ .

Let’s get started! 🏁

:::{card} Ragas Metrics and Evaluation
:link: get-started-evaluation
:link-type: ref

How to use the Ragas Metrics to evaluate your RAG pipelines.
:::

:::{card} Synthetic Testset Generation
:link: get-started-testset-generation
:link-type: ref

How to generate testset to assess your RAG pipelines
:::
:::{card} Monitoring
:link: get-started-monitoring
:link-type: ref

How to monitor your RAG systems in production.
:::
